#ifndef PDGH
#define PDGH

/******************************************************************************
               PDG Constants
*******************************************************************************/
#if defined (_WIN32)
   #if !defined(WIN32)
     #define WIN32
   #endif
#endif

// flags
#define PGFLAG_RETURN_MSG_ID  0x1

#define PGPROP_AUTHOR            0       // author of the document
#define PGPROP_TITLE             1       // title of the document
#define PGPROP_PRODUCER          2       // producer of the document
#define PGPROP_SUBJECT           3       // subject of the document
#define PGPROP_KEYWORDS          4       // keywords of the document
#define PGPROP_CRE_DATE          5       // date of the document
#define PGPROP_MOD_DATE          6       // ModDate of the document
#define PGPROP_COMPRESS_TEXT     7       // True to compress text
#define PGPROP_EMBED_FONTS       8       // True to always embed fonts
#define PGPROP_BOOKMARK          9       // Create bookmarks
#define PGPROP_HYPERLINK        10       // Create hyperlinks
#define PGPROP_MAC_COMPATIBLE   11       // True to create mac compatible pdf file
#define PGPROP_PERM_FLAGS       12       // permission flags PERM_ constants
#define PGPROP_USER_PASSWORD    13       // user password
#define PGPROP_OWNER_PASSWORD   14       // ownwer password
#define PGPROP_EXACT_TEXT_PLACEMENT 15   // place characters at exact positions
#define PGPROP_BATCH            16       // faster processing for smaller files when multiple conversions done in the same session
#define PGPROP_NO_CACHING       17       // disable caaching when writing to disk
#define PGPROP_HI_RES           18       // hi res pdf
#define PGPROP_PDFA_1B          19       // minimum compliance pdf/a-1b
#define PGPROP_PDFA             20       // minimum compliance pdf/a
  
  
#define PERM_PRINT            0x4     // these values are specified by the pdf spec - permission flags
#define PERM_MOD              0x28
#define PERM_COPY             0x10

#define PERM_ALL              (PERM_PRINT|PERM_MOD|PERM_COPY)

#define BRDRTYPE_SINGLE           0
#define BRDRTYPE_DBL              1
#define BRDRTYPE_TRIPLE           2
#define BRDRTYPE_SHADOW           3
#define BRDRTYPE_THICK_THIN       4
#define BRDRTYPE_THICK_THIN_THICK 5
#define BRDRTYPE_THIN_THICK       6
#define BRDRTYPE_THIN_THICK_THIN  7
#define BRDRTYPE_NONE             8

// Error messages
#define MSG_FILE_NOT_FOUND     1
#define MSG_NO_EDITOR_INSTANCE 2
#define MSG_READ_ERROR         3
#define MSG_WRITE_ERROR        4
#define MSG_MEMORY_LOCK        5
#define MSG_NO_FILE_SIGNATURE  6
#define MSG_BAD_RTF_FILE       7
#define MSG_BAD_HTML_FILE      8
#define MSG_EXPIRED            9
#define MSG_BAD_RTF_DATA      10
#define MSG_LICENSE_EXCEEDED   15
#define MSG_BAD_LICENSE_NUMBER 16
#define MSG_BAD_LICENSE_KEY    17
#define MSG_INVALID_SERVER_LICENSE 18

#define MSG_OTHER             99

/******************************************************************************
    WIN32 specific defines
*******************************************************************************/
#if defined (WIN32)
   #define PDG_HUGE
   #define _export
#else
   #define PDG_HUGE huge 
#endif


/****************************************************************************
   Instructions for packing the following structure
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack(1)
#endif

/****************************************************************************
   Instructions to resume the default structure packing.
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack()
#endif


/******************************************************************************
                     Editor Function Prototype
   When calling PDG from a C program, leave the PDG_CPLUSPLUS symbol undefined.

   When calling PDG from a C++ program, define the PDG_CPLUSPLUS as following:

   #define PDG_CPLUSPLUS extern "C"
   #include "ter.h"
*******************************************************************************/
#ifndef PDG_CPLUSPLUS
   #if defined(__cplusplus) 
      #define PDG_CPLUSPLUS extern "C"
   #else
      #define PDG_CPLUSPLUS
   #endif
#endif

PDG_CPLUSPLUS DWORD   WINAPI _export PdgNewSession();
PDG_CPLUSPLUS BOOL    WINAPI _export PdgEndSession(DWORD);
PDG_CPLUSPLUS DWORD   WINAPI _export PdgNewDocObject(DWORD);
PDG_CPLUSPLUS DWORD   WINAPI _export PdgGenerateReportFile(DWORD, DWORD,LPBYTE);
PDG_CPLUSPLUS HGLOBAL WINAPI _export PdgGenerateReportBuffer(DWORD, DWORD, LPINT);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgHandleToStr(LPBYTE,int,HANDLE);
PDG_CPLUSPLUS int     WINAPI _export PdgGetLastMessage(DWORD,LPBYTE,LPBYTE);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgResetLastMessage(DWORD);
PDG_CPLUSPLUS DWORD   WINAPI _export PdgSetFlags(DWORD,BOOL,int);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgSetTextProp(DWORD,int,LPBYTE);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgSetBoolProp(DWORD,int,BOOL);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgSetNumProp(DWORD,int,int);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgHandleToByteArray(LPBYTE,int,HANDLE);
PDG_CPLUSPLUS int     WINAPI _export PdgSetLicenseInfo(LPBYTE, LPBYTE, LPBYTE);
PDG_CPLUSPLUS int     WINAPI _export PdgSetLicenseInfoU(LPWORD,LPWORD,LPWORD);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgSetInServer(BOOL);
PDG_CPLUSPLUS int     WINAPI _export PdgGetLicenseStatus();
                                                                  
// undocumented functions - please contact Sub Systems before using these functions
PDG_CPLUSPLUS BOOL    WINAPI _export PdgSetPaperSize(DWORD, int, int, int);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgSetPaperOrient(DWORD, int);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgSetPageMargin(DWORD, int, int, int, int);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgSetPageBorder(DWORD, int, int, int, COLORREF);
PDG_CPLUSPLUS LPBYTE  WINAPI _export PdgFileToMemPtr(LPBYTE, DWORD *);
PDG_CPLUSPLUS BOOL    WINAPI _export PdgMemToFile(LPBYTE, HGLOBAL, int);


#endif
